# -*- coding: utf-8 -*-
from django.conf.urls.defaults import patterns, url

urlpatterns = patterns('webapp.views',
    url(r'^$', 'home', name='home'),

    # STUDENT
    url(r'student/view/$', 'student_view', name='student_view'),
    url(r'student/(?P<pk>\d+)/view/$', 'student_view', name='student_view'),
    url(r'student/(?P<pk>\d+)/delete/$', 'student_delete', name='student_delete'),
    url(r'student/(?P<pk>\d+)/edit/$', 'student_edit', name='student_edit'),
    url(r'student/add/$', 'student_add', name='student_add'),
    # url(r'student/(?P<pk>\d+)/career/(?P<pk>\d+)/$', 'career_assign', name='career_assign'),

    # TEACHER
    url(r'teacher/view/$', 'teacher_view', name='teacher_view'),
    url(r'teacher/(?P<pk>\d+)/view/$', 'teacher_view', name='teacher_view'),
    url(r'teacher/(?P<pk>\d+)/delete/$', 'teacher_delete', name='teacher_delete'),
    url(r'teacher/(?P<pk>\d+)/edit/$', 'teacher_edit', name='teacher_edit'),
    url(r'teacher/add/$', 'teacher_add', name='teacher_add'),

    # QUIZ
    url(r'quiz/view/$', 'quiz_view', name='quiz_view'),
    url(r'quiz/(?P<pk>\d+)/view/$', 'quiz_view', name='quiz_view'),
    url(r'quiz/(?P<pk>\d+)/delete/$', 'quiz_delete', name='quiz_delete'),
    url(r'quiz/(?P<pk>\d+)/edit/$', 'quiz_edit', name='quiz_edit'),
    url(r'quiz/add/$', 'quiz_add', name='quiz_add'),
    url(r'quiz/(?P<pk>\d+)/question/add/$', 'quiz_add_question', name='quiz_add_question'),

    # CAREER
    url(r'career/view/$', 'career_view', name='career_view'),
    url(r'career/(?P<pk>\d+)/view/$', 'career_view', name='career_view'),
    url(r'career/(?P<pk>\d+)/delete/$', 'career_delete', name='career_delete'),
    url(r'career/(?P<pk>\d+)/edit/$', 'career_edit', name='career_edit'),
    url(r'career/add/$', 'career_add', name='career_add'),
)




# -*- coding: utf-8 -*-
from django.contrib.auth.models import User
from django.db import models

from hvad.models import TranslatableModel, TranslatedFields
from hvad.manager import TranslationManager

class Quiz(TranslatableModel):
    short_description = models.CharField(max_length=128)
    translations = TranslatedFields(
        title = models.CharField(max_length=256, null=True, blank=True),
        description = models.TextField(null=True, blank=True)
    )

    def __unicode__(self):
        return u'%s' % self.short_description

    def get_questions(self):
        return Question.objects.get_questions_for_quiz(self.id)

    class Meta:
        verbose_name_plural = 'Quizzes'


class Answer(TranslatableModel):
    short_description = models.CharField(max_length=128)
    translations = TranslatedFields(
        description = models.TextField(null=True, blank=True)
    )


class QuestionManager(TranslationManager):
    def get_questions_for_quiz(self, quiz):
        return self.get_query_set().filter(quiz=quiz).order_by('order')

class Question(TranslatableModel):
    short_description = models.CharField(max_length=128)
    quiz = models.ForeignKey('Quiz')
    order = models.IntegerField(null=True, blank=True)
    translations = TranslatedFields(
        title = models.CharField(max_length=256, null=True, blank=True),
        description = models.TextField(null=True, blank=True),
        help_text = models.TextField(null=True, blank=True)
    )

    objects = QuestionManager()


class QuizToCareer(models.Model):
    quiz = models.ForeignKey('Quiz')
    career = models.ForeignKey('Career')
    passed = models.BooleanField(default=False)
    due_date = models.DateField(null=True, blank=True)


class Career(models.Model):
    user = models.ForeignKey(User)
    quizzes = models.ManyToManyField(Quiz, null=True, blank=True,
                                through='QuizToCareer')
    

class Student(models.Model):
    user = models.ForeignKey(User)

    def __unicode__(self):
        return u'%s' % self.user.username


class Teacher(models.Model):
    user = models.ForeignKey(User)
    students = models.ManyToManyField('Student', null=True, blank=True,
                                 through='StudentToTeacher')

    def __unicode__(self):
        return u'%s' % self.user.username


class StudentToTeacher(models.Model):
    student = models.ForeignKey('Student')
    teacher = models.ForeignKey('Teacher')

    



# -*- coding: utf-8 -*-
from django import forms

from webapp.models import Student, Teacher, Quiz, Question, Career

class StudentForm(forms.ModelForm):
    class Meta:
        model = Student

class TeacherForm(forms.ModelForm):
    class Meta:
        model = Teacher

class QuizForm(forms.ModelForm):
    class Meta:
        model = Quiz

class QuestionForm(forms.ModelForm):
    class Meta:
        model = Question

class CareerForm(forms.ModelForm):
    class Meta:
        model = Career 



from django import template

from webapp.models import Career

register = template.Library()

@register.inclusion_tag('webapp/get_careers.html')
def get_careers(user):
    careers = Career.objects.filter(user=user)
    return {'careers': careers}



# -*- coding: utf-8 -*-
from django.contrib.auth.decorators import user_passes_test, login_required
from django.shortcuts import render, redirect, get_object_or_404

from webapp.models import Student, Teacher, Quiz, Question, Career
from webapp.forms import StudentForm, TeacherForm, QuizForm, QuestionForm, CareerForm


def home(request):
    context = []
    if request.user.is_authenticated():
        context = {
        }
        return render(request, 'webapp/home.html', context)
    

@login_required
def student_view(request, pk=None):
    if pk is None:
        students = Student.objects.all()
        context = {
            'students': students
        }
        return render(request, 'webapp/student_list_view.html', context)
    else:
        student = Student.objects.get(pk=pk)
        context = {
            'student': student
        }
        return render(request, 'webapp/student_view.html', context)

@user_passes_test(lambda u: u.is_superuser)
def student_delete(request, pk):
    student = Student.objects.get(pk=pk)
    student.delete()

    return redirect('student_view')

@user_passes_test(lambda u: u.is_superuser)
def student_edit(request, pk):
    student = get_object_or_404(Student, pk=pk)
    if request.method == 'POST':
        form = StudentForm(request.POST, instance=student)
        if form.is_valid():
            form.save()
    else:
        form = StudentForm(instance=student)

    context = {
        'form': form
    }
    return render(request, 'webapp/student_edit.html', context)

@user_passes_test(lambda u: u.is_superuser)
def student_add(request):
    form = StudentForm(request.POST or None)
    if request.method == 'POST':
        if form.is_valid():
            form.save()
            return redirect('student_view')

    context = {
        'form': form
    }
    return render(request, 'webapp/student_edit.html', context)

@login_required
def teacher_view(request, pk=None):
    if pk is None:
        teachers = Teacher.objects.all()
        context = {
            'teachers': teachers
        }
        return render(request, 'webapp/teacher_list_view.html', context)
    else:
        teacher = Teacher.objects.get(pk=pk)
        context = {
            'teacher': teacher
        }
        return render(request, 'webapp/teacher_view.html', context)

@user_passes_test(lambda u: u.is_superuser)
def teacher_delete(request, pk):
    teacher = Teacher.objects.get(pk=pk)
    teacher.delete()

    return redirect('teacher_view')

@user_passes_test(lambda u: u.is_superuser)
def teacher_edit(request, pk):
    teacher = get_object_or_404(Teacher, pk=pk)
    if request.method == 'POST':
        form = TeacherForm(request.POST, instance=teacher)
        if form.is_valid():
            form.save()
    else:
        form = TeacherForm(instance=teacher)

    context = {
        'form': form
    }
    return render(request, 'webapp/teacher_edit.html', context)

@user_passes_test(lambda u: u.is_superuser)
def teacher_add(request):
    form = TeacherForm(request.POST or None)
    if request.method == 'POST':
        if form.is_valid():
            form.save()
            return redirect('teacher_view')

    context = {
        'form': form
    }
    return render(request, 'webapp/teacher_edit.html', context)

@login_required
def quiz_view(request, pk=None):
    if pk is None:
        quizzes = Quiz.objects.all()
        context = {
            'quizzes': quizzes
        }
        return render(request, 'webapp/quiz_list_view.html', context)
    else:
        quiz = Quiz.objects.get(pk=pk)
        context = {
            'quiz': quiz
        }
        return render(request, 'webapp/quiz_view.html', context)

@user_passes_test(lambda u: u.is_superuser)
def quiz_delete(request, pk):
    quiz = Quiz.objects.get(pk=pk)
    quiz.delete()

    return redirect('quiz_view')

@user_passes_test(lambda u: u.is_superuser)
def quiz_edit(request, pk):
    quiz = get_object_or_404(Quiz, pk=pk)
    if request.method == 'POST':
        form = QuizForm(request.POST, instance=quiz)
        if form.is_valid():
            form.save()
    else:
        form = QuizForm(instance=quiz)

    context = {
        'form': form
    }
    return render(request, 'webapp/quiz_edit.html', context)

@login_required
def quiz_add_question(request, pk):
    quiz = get_object_or_404(Quiz, pk=pk)
    if request.method == 'POST':
        form = QuestionForm(request.POST)
        if form.is_valid():
            form.save()
            return redirect('quiz_view', pk=quiz.id)

    else:
        form = QuestionForm(initial={ 'quiz' : quiz})
    
    context = {
        'form': form
    }
    return render(request, 'webapp/quiz_add_question.html', context)

@user_passes_test(lambda u: u.is_superuser)
def quiz_add(request):
    form = QuizForm(request.POST or None)
    if request.method == 'POST':
        if form.is_valid():
            form.save()
            return redirect('quiz_view')

    context = {
        'form': form
    }
    return render(request, 'webapp/quiz_edit.html', context)

@login_required
def career_view(request, pk=None):
    if pk is None:
        careers = Career.objects.all()
        context = {
            'careers': careers
        }
        return render(request, 'webapp/career_list_view.html', context)
    else:
        career = Career.objects.get(pk=pk)
        context = {
            'career': career
        }
        return render(request, 'webapp/career_view.html', context)

@user_passes_test(lambda u: u.is_superuser)
def career_delete(request, pk):
    career = Career.objects.get(pk=pk)
    career.delete()

    return redirect('career_view')

@user_passes_test(lambda u: u.is_superuser)
def career_edit(request, pk):
    career = get_object_or_404(Career, pk=pk)
    if request.method == 'POST':
        form = CareerForm(request.POST, instance=career)
        if form.is_valid():
            form.save()
    else:
        form = CareerForm(instance=career)

    context = {
        'form': form
    }
    return render(request, 'webapp/career_edit.html', context)

@user_passes_test(lambda u: u.is_superuser)
def career_add(request):
    form = CareerForm(request.POST or None)
    if request.method == 'POST':
        if form.is_valid():
            form.save()
            return redirect('career_view')

    context = {
        'form': form
    }
    return render(request, 'webapp/career_edit.html', context)



from django.contrib import admin
from hvad.admin import TranslatableAdmin

from webapp.models import Question, Quiz, Student, Career, Teacher, QuizToCareer

class QuestionInline(admin.StackedInline):
    model = Question
    extra = 3

class QuizToCareerInline(admin.StackedInline):
    model = QuizToCareer
    extra = 3

class QuizAdmin(TranslatableAdmin):
    inlines = [QuestionInline]
    
class CareerAdmin(admin.ModelAdmin):
    inlines = [QuizToCareerInline]


admin.site.register(Career, CareerAdmin)
admin.site.register(Quiz, QuizAdmin)
admin.site.register(Student)
admin.site.register(Teacher)



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'QuizTranslation'
        db.create_table('webapp_quiz_translation', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=256, null=True, blank=True)),
            ('description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('language_code', self.gf('django.db.models.fields.CharField')(max_length=15, db_index=True)),
            ('master', self.gf('django.db.models.fields.related.ForeignKey')(related_name='translations', null=True, to=orm['webapp.Quiz'])),
        ))
        db.send_create_signal('webapp', ['QuizTranslation'])

        # Adding unique constraint on 'QuizTranslation', fields ['language_code', 'master']
        db.create_unique('webapp_quiz_translation', ['language_code', 'master_id'])

        # Adding model 'Quiz'
        db.create_table('webapp_quiz', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('short_description', self.gf('django.db.models.fields.CharField')(max_length=128)),
        ))
        db.send_create_signal('webapp', ['Quiz'])

        # Adding model 'AnswerTranslation'
        db.create_table('webapp_answer_translation', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('language_code', self.gf('django.db.models.fields.CharField')(max_length=15, db_index=True)),
            ('master', self.gf('django.db.models.fields.related.ForeignKey')(related_name='translations', null=True, to=orm['webapp.Answer'])),
        ))
        db.send_create_signal('webapp', ['AnswerTranslation'])

        # Adding unique constraint on 'AnswerTranslation', fields ['language_code', 'master']
        db.create_unique('webapp_answer_translation', ['language_code', 'master_id'])

        # Adding model 'Answer'
        db.create_table('webapp_answer', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('short_description', self.gf('django.db.models.fields.CharField')(max_length=128)),
        ))
        db.send_create_signal('webapp', ['Answer'])

        # Adding model 'QuestionTranslation'
        db.create_table('webapp_question_translation', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=256, null=True, blank=True)),
            ('description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('help_text', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('language_code', self.gf('django.db.models.fields.CharField')(max_length=15, db_index=True)),
            ('master', self.gf('django.db.models.fields.related.ForeignKey')(related_name='translations', null=True, to=orm['webapp.Question'])),
        ))
        db.send_create_signal('webapp', ['QuestionTranslation'])

        # Adding unique constraint on 'QuestionTranslation', fields ['language_code', 'master']
        db.create_unique('webapp_question_translation', ['language_code', 'master_id'])

        # Adding model 'Question'
        db.create_table('webapp_question', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('short_description', self.gf('django.db.models.fields.CharField')(max_length=128)),
            ('quiz', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['webapp.Quiz'])),
            ('order', self.gf('django.db.models.fields.IntegerField')(null=True, blank=True)),
        ))
        db.send_create_signal('webapp', ['Question'])

        # Adding model 'QuizToCareer'
        db.create_table('webapp_quiztocareer', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('quiz', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['webapp.Quiz'])),
            ('career', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['webapp.Career'])),
            ('passed', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('due_date', self.gf('django.db.models.fields.DateField')(null=True, blank=True)),
        ))
        db.send_create_signal('webapp', ['QuizToCareer'])

        # Adding model 'Career'
        db.create_table('webapp_career', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'])),
        ))
        db.send_create_signal('webapp', ['Career'])

        # Adding model 'Student'
        db.create_table('webapp_student', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'])),
        ))
        db.send_create_signal('webapp', ['Student'])

        # Adding model 'Teacher'
        db.create_table('webapp_teacher', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'])),
        ))
        db.send_create_signal('webapp', ['Teacher'])

        # Adding model 'StudentToTeacher'
        db.create_table('webapp_studenttoteacher', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('student', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['webapp.Student'])),
            ('teacher', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['webapp.Teacher'])),
        ))
        db.send_create_signal('webapp', ['StudentToTeacher'])


    def backwards(self, orm):
        # Removing unique constraint on 'QuestionTranslation', fields ['language_code', 'master']
        db.delete_unique('webapp_question_translation', ['language_code', 'master_id'])

        # Removing unique constraint on 'AnswerTranslation', fields ['language_code', 'master']
        db.delete_unique('webapp_answer_translation', ['language_code', 'master_id'])

        # Removing unique constraint on 'QuizTranslation', fields ['language_code', 'master']
        db.delete_unique('webapp_quiz_translation', ['language_code', 'master_id'])

        # Deleting model 'QuizTranslation'
        db.delete_table('webapp_quiz_translation')

        # Deleting model 'Quiz'
        db.delete_table('webapp_quiz')

        # Deleting model 'AnswerTranslation'
        db.delete_table('webapp_answer_translation')

        # Deleting model 'Answer'
        db.delete_table('webapp_answer')

        # Deleting model 'QuestionTranslation'
        db.delete_table('webapp_question_translation')

        # Deleting model 'Question'
        db.delete_table('webapp_question')

        # Deleting model 'QuizToCareer'
        db.delete_table('webapp_quiztocareer')

        # Deleting model 'Career'
        db.delete_table('webapp_career')

        # Deleting model 'Student'
        db.delete_table('webapp_student')

        # Deleting model 'Teacher'
        db.delete_table('webapp_teacher')

        # Deleting model 'StudentToTeacher'
        db.delete_table('webapp_studenttoteacher')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'webapp.answer': {
            'Meta': {'object_name': 'Answer'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'short_description': ('django.db.models.fields.CharField', [], {'max_length': '128'})
        },
        'webapp.answertranslation': {
            'Meta': {'unique_together': "[('language_code', 'master')]", 'object_name': 'AnswerTranslation', 'db_table': "'webapp_answer_translation'"},
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language_code': ('django.db.models.fields.CharField', [], {'max_length': '15', 'db_index': 'True'}),
            'master': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'translations'", 'null': 'True', 'to': "orm['webapp.Answer']"})
        },
        'webapp.career': {
            'Meta': {'object_name': 'Career'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'quizzes': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['webapp.Quiz']", 'null': 'True', 'through': "orm['webapp.QuizToCareer']", 'blank': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"})
        },
        'webapp.question': {
            'Meta': {'object_name': 'Question'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'quiz': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['webapp.Quiz']"}),
            'short_description': ('django.db.models.fields.CharField', [], {'max_length': '128'})
        },
        'webapp.questiontranslation': {
            'Meta': {'unique_together': "[('language_code', 'master')]", 'object_name': 'QuestionTranslation', 'db_table': "'webapp_question_translation'"},
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'help_text': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language_code': ('django.db.models.fields.CharField', [], {'max_length': '15', 'db_index': 'True'}),
            'master': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'translations'", 'null': 'True', 'to': "orm['webapp.Question']"}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '256', 'null': 'True', 'blank': 'True'})
        },
        'webapp.quiz': {
            'Meta': {'object_name': 'Quiz'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'short_description': ('django.db.models.fields.CharField', [], {'max_length': '128'})
        },
        'webapp.quiztocareer': {
            'Meta': {'object_name': 'QuizToCareer'},
            'career': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['webapp.Career']"}),
            'due_date': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'passed': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'quiz': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['webapp.Quiz']"})
        },
        'webapp.quiztranslation': {
            'Meta': {'unique_together': "[('language_code', 'master')]", 'object_name': 'QuizTranslation', 'db_table': "'webapp_quiz_translation'"},
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language_code': ('django.db.models.fields.CharField', [], {'max_length': '15', 'db_index': 'True'}),
            'master': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'translations'", 'null': 'True', 'to': "orm['webapp.Quiz']"}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '256', 'null': 'True', 'blank': 'True'})
        },
        'webapp.student': {
            'Meta': {'object_name': 'Student'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"})
        },
        'webapp.studenttoteacher': {
            'Meta': {'object_name': 'StudentToTeacher'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'student': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['webapp.Student']"}),
            'teacher': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['webapp.Teacher']"})
        },
        'webapp.teacher': {
            'Meta': {'object_name': 'Teacher'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'students': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['webapp.Student']", 'null': 'True', 'through': "orm['webapp.StudentToTeacher']", 'blank': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"})
        }
    }

    complete_apps = ['webapp']


from setuptools import setup, find_packages
from career import __version__ as version

with open('README.rst') as f:
    long_description = f.read()

setup(
    name = 'career',
    version = version,
    description = 'The very basic to start some elearning activity',
    long_description = long_description,
    author = 'Daniel Tellez',
    author_email = 'danieltellez@flossfriday.com',
    url = 'https://github.com/danieltellez/career',
    packages = find_packages(
        exclude = [
            'testproject',
            'testproject.app',
        ],
    ),
    zip_safe=False,
    include_package_data = True,
    install_requires=[
        'Django>=1.3',
        'django-hvad',
    ],
    classifiers = [
        "Development Status :: 3 - Alpha",
        "Framework :: Django",
        "Intended Audience :: Other Audience",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Education",
    ]
)


